@@ -2,7 +2,8 @@ from typing import List, Set, Dict, NewType, Tuple
 from uuid import uuid4
 import os
 from ..transform import Transform
-from ..exceptions import BakerError, TagConflictError
+from ..exceptions import BakerError, TagConflictError, BakerUnsupportedError
+from ..workarounds.annot import is_fileset
 
 
 def _build_scope_diagram(steps):
@@ -52,33 +53,18 @@ def _determine_sequence_interface(scope_diagram, exposed_intermediates):
     return [seq_input_tags, seq_output_tags]
 
 
-def sequence(seq_steps: List[Transform], exposed_intermediates: Set[str] = set()):
-    # Perform validation that the sequence makes sense.
-    if len(seq_steps) < 1:
-        raise BakerError("Cannot sequence fewer than 1 event")
-    if len(seq_steps) == 1:
-        return seq_steps[0]
-
-    scope_diagram = _build_scope_diagram(seq_steps)
-    seq_input_tags, seq_output_tags = _determine_sequence_interface(
-        scope_diagram, exposed_intermediates
-    )
-
+def _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps):
     class Sequence(Transform):
         nonlocal seq_input_tags, seq_output_tags, seq_steps
         input_tags = seq_input_tags
         output_tags = seq_output_tags
-
         steps = seq_steps
 
         def _generate_temp_filename(self, sid):
-            # TODO: This really should be in transform
-            folder = "/tmp/tinybaker-{}".format(sid)
-            if not os.path.exists(folder):
-                os.mkdir(folder)
-            return "{}/{}".format(folder, uuid4())
+            target_fs = self.context.fs_for_intermediates
+            return "{}://tinybaker-{}__{}".format(target_fs, sid, uuid4())
 
-        def script(self, runtime):
+        def script(self):
             sequence_instance_id = uuid4()
             instances = []
 
@@ -107,11 +93,16 @@ def sequence(seq_steps: List[Transform], exposed_intermediates: Set[str] = set()
                 input_paths.update(input_paths_from_sequence)
                 input_paths.update(input_paths_from_scope)
 
-                # Generate output fileset
-                generated_output_paths = {
-                    tag: self._generate_temp_filename(sequence_instance_id)
-                    for tag in step.output_tags - self.output_tags
-                }
+                generated_output_paths = {}
+                for tag in step.output_tags - self.output_tags:
+                    if is_fileset(tag):
+                        raise BakerUnsupportedError(
+                            "TinyBaker does not support intermediate filesets with autogenerated paths"
+                        )
+                    generated_output_paths[tag] = self._generate_temp_filename(
+                        sequence_instance_id
+                    )
+
                 output_paths_from_sequence = {
                     tag: seq_output_paths[tag]
                     for tag in seq_output_paths
@@ -122,7 +113,12 @@ def sequence(seq_steps: List[Transform], exposed_intermediates: Set[str] = set()
                 output_paths.update(output_paths_from_sequence)
 
                 instances.append(
-                    step(input_paths=input_paths, output_paths=output_paths)
+                    step(
+                        input_paths=input_paths,
+                        output_paths=output_paths,
+                        context=self.context,
+                        overwrite=self.overwrite,
+                    )
                 )
 
                 # maintain state
@@ -130,6 +126,20 @@ def sequence(seq_steps: List[Transform], exposed_intermediates: Set[str] = set()
 
             # Phase 2: Run instances
             for instance in instances:
-                instance.build(runtime)
+                instance._exec_with_run_info(self._current_run_info)
 
     return Sequence
+
+
+def sequence(seq_steps: List[Transform], exposed_intermediates: Set[str] = set()):
+    # Perform validation that the sequence makes sense.
+    if len(seq_steps) < 1:
+        raise BakerError("Cannot sequence fewer than 1 event")
+    if len(seq_steps) == 1:
+        return seq_steps[0]
+
+    scope_diagram = _build_scope_diagram(seq_steps)
+    seq_input_tags, seq_output_tags = _determine_sequence_interface(
+        scope_diagram, exposed_intermediates
+    )
+    return _build_sequence_class(seq_input_tags, seq_output_tags, seq_steps)
