@@ -5,7 +5,15 @@ class BakerError(Exception):
     pass
 
 
-class TagConflictError(Exception):
+class BakerUnsupportedError(Exception):
+    pass
+
+
+class TagConflictError(BakerError):
+    pass
+
+
+class SeriousErrorThatYouShouldOpenAnIssueForIfYouGet(BakerError):
     pass
 
 
